@@ -2,9 +2,11 @@
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 # 
-# $Id: Info.pm,v 1.4 2006/05/24 11:14:27 gavin Exp $
+# $Id: Info.pm,v 1.6 2006/07/11 11:40:02 gavin Exp $
 package Net::EPP::Frame::Command::Info;
+use Net::EPP::Frame::Command::Info::Contact;
 use Net::EPP::Frame::Command::Info::Domain;
+use Net::EPP::Frame::Command::Info::Host;
 use base qw(Net::EPP::Frame::Command);
 use strict;
 
